#include <e.h>
#include "e_mod_main.h"

/* actual module specifics */
static void _e_mod_action_exebuf_cb(E_Object * obj, const char *params);

static int _e_mod_run_defer_cb(void *data);

static void _e_mod_run_cb(void *data, E_Menu * m, E_Menu_Item * mi);

static void _e_mod_menu_add(void *data, E_Menu * m);

static E_Module *conf_module = NULL;

static E_Action *act = NULL;

/* module setup */
EAPI E_Module_Api e_modapi = {
   E_MODULE_API_VERSION,
   "Effects"
};

EAPI void *
e_modapi_init(E_Module * m)
{
   conf_module = m;

   if (!e_config->use_composite)
     {
	e_config->use_composite = 1;
	e_config_save_queue();
     }

   /* add module supplied action */
   act = e_action_add("effects");
   if (act)
     {
	act->func.go = _e_mod_action_exebuf_cb;
	e_action_predef_name_set("Launch", "Effects", "effects", NULL, NULL, 0);
     }

   e_module_delayed_set(m, 1);
   e_effects_init();
   return m;
}

EAPI int
e_modapi_shutdown(E_Module * m)
{
   /* remove module-supplied menu additions */
   if (act)
     {
	e_action_predef_name_del("Launch", "Effects");
	e_action_del("effects");
	act = NULL;
     }

   conf_module = NULL;
   e_effects_shutdown();
   return 1;
}

EAPI int
e_modapi_save(E_Module * m)
{
   return 1;
}

/* action callback */
static void
_e_mod_action_exebuf_cb(E_Object * obj, const char *params)
{
   E_Zone *zone = NULL;

   if (obj)
     {
	if (obj->type == E_MANAGER_TYPE)
	   zone = e_util_zone_current_get((E_Manager *) obj);
	else if (obj->type == E_CONTAINER_TYPE)
	   zone = e_util_zone_current_get(((E_Container *) obj)->manager);
	else if (obj->type == E_ZONE_TYPE)
	   zone = e_util_zone_current_get(((E_Zone *) obj)->container->manager);
	else
	   zone = e_util_zone_current_get(e_manager_current_get());
     }

   if (!zone)
      zone = e_util_zone_current_get(e_manager_current_get());

   if (zone)
      e_effects_apply(zone);
}
